@@ -387,7 +387,7 @@ class Stock:
 		tr = soup.find_all('tr', {'class': "insider-sale-row-2"})
 		return [i.get_text() for i in tr]
 
-	def social_media_sentiment(self.ticker, num_of_tweets=50): # Also reddit sentiment, and twitter
+	def social_media_sentiment(self, num_of_tweets=50): # Also reddit sentiment, and twitter
 		# Twitter
 		load_dotenv()
 		consumer_key = os.getenv('API_KEY')
